@@ -3,16 +3,24 @@ package App::Critique::Plugin::UI;
 use strict;
 use warnings;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use Term::ReadKey  ();
 use Number::Format ();
 
-use constant TERM_WIDTH => eval { local $SIG{__WARN__} = sub {''}; (Term::ReadKey::GetTerminalSize())[0] // 80 };
-use constant HR_ERROR   => ('== ERROR '.('=' x (TERM_WIDTH - 9)));
-use constant HR_DARK    => ('=' x TERM_WIDTH);
-use constant HR_LIGHT   => ('-' x TERM_WIDTH);
+sub TERM_WIDTH () {
+    my $size = eval {
+        local $SIG{__WARN__} = sub {''};
+        ( Term::ReadKey::GetTerminalSize() )[0];
+    } || 80;
+
+    return $size;
+}
+
+use constant HR_ERROR => ( '== ERROR ' . ( '=' x ( TERM_WIDTH - 9 ) ) );
+use constant HR_DARK  => ( '=' x TERM_WIDTH );
+use constant HR_LIGHT => ( '-' x TERM_WIDTH );
 
 use App::Critique -ignore;
 
@@ -86,7 +94,7 @@ App::Critique::Plugin::UI - UI elements for App::Critique
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
